@@ -182,7 +182,10 @@ class BaseListWindow(BaseWindow):
             text=u'Закрыть',
             handler='close'
         )
-        self._mro_exclude_list.append(self.close_btn)
+        self._mro_exclude_list.extend([
+            self.close_btn,
+            self.grid.top_bar.button_refresh
+        ])
 
     def _do_layout(self):
         """
@@ -350,6 +353,16 @@ class BaseSelectWindow(BaseListWindow):
         self.column_name_on_select = params['column_name_on_select']
 
 
+class BaseMultiSelectWindow(BaseSelectWindow):
+    """
+    Окно множественного выбора в ExtMultiSelectWindow
+    """
+    _xtype = 'objectpack-multi-select-window'
+
+    def set_params(self, params):
+        super(BaseMultiSelectWindow, self).set_params(params)
+        self._enable_multi_select()
+
 #==============================================================================
 # ColumnsConstructor
 #==============================================================================
@@ -743,6 +756,10 @@ def _create_control_for_field(f, model_register=None, **kwargs):
 
     elif isinstance(f, django_models.IntegerField):
         ctl = ext.ExtNumberField(**kwargs)
+        ctl.allow_decimals = False
+        if isinstance(f, (django_models.PositiveIntegerField,
+                          django_models.PositiveSmallIntegerField)):
+            ctl.allow_negative = False
 
     elif isinstance(f, django_models.FloatField):
         ctl = ext.ExtNumberField(**kwargs)
